Index: uspace/srv/loader/arch/ia32/ia32.s
===================================================================
--- uspace/srv/loader/arch/ia32/ia32.s	(revision cc1f8d49ea50ec53cdbef1c6e641762fee657fb0)
+++ uspace/srv/loader/arch/ia32/ia32.s	(revision 3cc110fd26aa526528a9c7a4962a95fc10e58feb)
@@ -40,7 +40,7 @@
 	movl 0x8(%ebp), %eax
 
-	# %ebx := pcb
-	# pcb is passed to the entry point int %ebx
-	mov 0xc(%ebp), %ebx
+	# %edi := pcb
+	# pcb is passed to the entry point in %edi
+	mov 0xc(%ebp), %edi
 
 	# Save a tiny bit of stack space
